@@ -62,9 +62,10 @@ typedef enum
 	SET_ENVIRONMENT_COMMAND,
 	UNLOAD_COMMAND,         /* Program loaded */
 	START_COMMAND,         
+	CONNECT_COMMAND,         
 	BREAK_LINE_COMMAND,		  /* Program loaded - Program stopped */
-	BREAK_FUNCTION_COMMAND,
-	BREAK_ADDRESS_COMMAND,	/* 0x10 */
+	BREAK_FUNCTION_COMMAND,  /* 0x10 */
+	BREAK_ADDRESS_COMMAND,
 	ENABLE_BREAK_COMMAND,
 	IGNORE_BREAK_COMMAND,
 	CONDITION_BREAK_COMMAND,
@@ -79,9 +80,11 @@ typedef enum
 	STEP_OUT_COMMAND,
 	RUN_COMMAND,		
 	RUN_TO_COMMAND,
+	RUN_FROM_COMMAND,			/* 0x20 */
 	STEPI_IN_COMMAND,
-	STEPI_OVER_COMMAND,			/* 0x20 */
+	STEPI_OVER_COMMAND,
 	RUN_TO_ADDRESS_COMMAND,
+	RUN_FROM_ADDRESS_COMMAND,
 	EXIT_COMMAND,
 	HANDLE_SIGNAL_COMMAND,
 	LIST_LOCAL_COMMAND,
@@ -93,10 +96,11 @@ typedef enum
 	INFO_FRAME_COMMAND,
 	INFO_ARGS_COMMAND,
 	INFO_VARIABLES_COMMAND,
-	SET_FRAME_COMMAND,
+	SET_FRAME_COMMAND,			/* 0x30 */
 	LIST_FRAME_COMMAND,
+	DUMP_STACK_TRACE_COMMAND,
 	UPDATE_REGISTER_COMMAND,
-	WRITE_REGISTER_COMMAND,		/* 0x30 */
+	WRITE_REGISTER_COMMAND,
 	EVALUATE_COMMAND,
 	INSPECT_COMMAND,
 	PRINT_COMMAND,
@@ -150,6 +154,9 @@ typedef enum
 	DMA_START_COMMAND =
 		START_COMMAND | RUN_PROGRAM |
 		NEED_PROGRAM_LOADED | NEED_PROGRAM_STOPPED,
+	DMA_CONNECT_COMMAND =
+		CONNECT_COMMAND | RUN_PROGRAM |
+		NEED_PROGRAM_LOADED | NEED_PROGRAM_STOPPED,
 	DMA_BREAK_LINE_COMMAND =
 		BREAK_LINE_COMMAND |
 		NEED_PROGRAM_LOADED | NEED_PROGRAM_STOPPED,
@@ -201,6 +208,9 @@ typedef enum
 	DMA_RUN_TO_COMMAND =
 		RUN_TO_COMMAND | RUN_PROGRAM |
 		NEED_PROGRAM_STOPPED,
+	DMA_RUN_FROM_COMMAND =
+		RUN_FROM_COMMAND | RUN_PROGRAM |
+		NEED_PROGRAM_STOPPED,
 	DMA_STEPI_IN_COMMAND =
 		STEPI_IN_COMMAND | RUN_PROGRAM |
 		NEED_PROGRAM_STOPPED,
@@ -210,6 +220,9 @@ typedef enum
 	DMA_RUN_TO_ADDRESS_COMMAND =
 		RUN_TO_ADDRESS_COMMAND | RUN_PROGRAM |
 		NEED_PROGRAM_STOPPED,
+	DMA_RUN_FROM_ADDRESS_COMMAND =
+		RUN_FROM_ADDRESS_COMMAND | RUN_PROGRAM |
+		NEED_PROGRAM_STOPPED,
 	DMA_EXIT_COMMAND =
 		EXIT_COMMAND | LOAD_PROGRAM |
 		NEED_PROGRAM_STOPPED,
@@ -249,6 +262,9 @@ typedef enum
 	DMA_LIST_FRAME_COMMAND =
 		LIST_FRAME_COMMAND |
 		NEED_PROGRAM_STOPPED | NEED_PROGRAM_RUNNING,
+	DMA_DUMP_STACK_TRACE_COMMAND =
+		DUMP_STACK_TRACE_COMMAND |
+		NEED_PROGRAM_STOPPED | NEED_PROGRAM_RUNNING,
 	DMA_UPDATE_REGISTER_COMMAND =
 		UPDATE_REGISTER_COMMAND |
 		NEED_PROGRAM_STOPPED | NEED_PROGRAM_RUNNING,
@@ -282,8 +298,11 @@ typedef enum
 	DMA_UPDATE_VARIABLE_COMMAND =
 	    UPDATE_VARIABLE | CANCEL_IF_PROGRAM_RUNNING |
 		NEED_PROGRAM_STOPPED | NEED_PROGRAM_RUNNING,
+	/* DMA_INTERRUPT_COMMAND doesn't automatically go in stop-program state
+	 * because sometimes it doesn't work. I don't know if it comes from anjuta,
+	 * anjuta-launcher, vte or gdb */
 	DMA_INTERRUPT_COMMAND =
-		INTERRUPT_COMMAND | STOP_PROGRAM |
+		INTERRUPT_COMMAND |
 		ASYNCHRONOUS | NEED_PROGRAM_RUNNING,
 } DmaDebuggerCommand;
 
@@ -299,6 +318,7 @@ struct _DmaQueueCommand
 			GList *dirs;
 		} load;
 		struct {
+			gchar *server;
 			gchar *args;
 			gboolean terminal;
 			gboolean stop;
@@ -417,12 +437,22 @@ dma_command_new (DmaDebuggerCommand cmd_type,...)
 		cmd->data.start.terminal = va_arg (args, gboolean);
 		cmd->data.start.stop = va_arg (args, gboolean);
 	    break;
+	case CONNECT_COMMAND:
+		cmd->data.start.server = g_strdup (va_arg (args, gchar *));
+		cmd->data.start.args = g_strdup (va_arg (args, gchar *));
+		cmd->data.start.terminal = va_arg (args, gboolean);
+		cmd->data.start.stop = va_arg (args, gboolean);
+	    break;
 	case RUN_COMMAND:
 		break;
 	case RUN_TO_COMMAND:
 		cmd->data.pos.file = g_strdup (va_arg (args, gchar *));
 		cmd->data.pos.line = va_arg (args, guint);
 		break;
+	case RUN_FROM_COMMAND:
+		cmd->data.pos.file = g_strdup (va_arg (args, gchar *));
+		cmd->data.pos.line = va_arg (args, guint);
+		break;
 	case STEP_IN_COMMAND:
 		break;
 	case STEP_OVER_COMMAND:
@@ -432,6 +462,9 @@ dma_command_new (DmaDebuggerCommand cmd_type,...)
 	case RUN_TO_ADDRESS_COMMAND:
 		cmd->data.pos.address = va_arg (args, guint);
 		break;
+	case RUN_FROM_ADDRESS_COMMAND:
+		cmd->data.pos.address = va_arg (args, guint);
+		break;
 	case STEPI_IN_COMMAND:
 		break;
 	case STEPI_OVER_COMMAND:
@@ -557,6 +590,10 @@ dma_command_new (DmaDebuggerCommand cmd_type,...)
 		cmd->callback = va_arg (args, IAnjutaDebuggerCallback);
 		cmd->user_data = va_arg (args, gpointer);
 		break;
+	case DUMP_STACK_TRACE_COMMAND:
+		cmd->callback = va_arg (args, IAnjutaDebuggerCallback);
+		cmd->user_data = va_arg (args, gpointer);
+		break;
 	case LIST_REGISTER_COMMAND:
 		cmd->callback = va_arg (args, IAnjutaDebuggerCallback);
 		cmd->user_data = va_arg (args, gpointer);
@@ -666,6 +703,12 @@ dma_queue_start (DmaDebuggerQueue *self, const gchar *args, gboolean terminal, g
 	return dma_debugger_queue_append (self, dma_command_new (DMA_START_COMMAND, args, terminal, stop));
 }
 
+gboolean
+dma_queue_connect (DmaDebuggerQueue *self, const gchar *server, const gchar *args, gboolean terminal, gboolean stop)
+{
+	return dma_debugger_queue_append (self, dma_command_new (DMA_CONNECT_COMMAND, server, args, terminal, stop));
+}
+
 gboolean
 dma_queue_unload (DmaDebuggerQueue *self)
 {
@@ -708,6 +751,12 @@ dma_queue_run_to (DmaDebuggerQueue *self, const gchar *file, gint line)
 	return dma_debugger_queue_append (self, dma_command_new (DMA_RUN_TO_COMMAND, file, line));
 }
 
+gboolean
+dma_queue_run_from (DmaDebuggerQueue *self, const gchar *file, gint line)
+{
+	return dma_debugger_queue_append (self, dma_command_new (DMA_RUN_FROM_COMMAND, file, line));
+}
+
 gboolean
 dma_queue_step_out (DmaDebuggerQueue *self)
 {
@@ -732,6 +781,12 @@ dma_queue_run_to_address (DmaDebuggerQueue *self, gulong address)
 	return dma_debugger_queue_append (self, dma_command_new (DMA_RUN_TO_ADDRESS_COMMAND, address));
 }
 
+gboolean
+dma_queue_run_from_address (DmaDebuggerQueue *self, gulong address)
+{
+	return dma_debugger_queue_append (self, dma_command_new (DMA_RUN_FROM_ADDRESS_COMMAND, address));
+}
+
 gboolean
 dma_queue_exit (DmaDebuggerQueue *self)
 {
@@ -864,6 +919,12 @@ dma_queue_list_frame (DmaDebuggerQueue *self, IAnjutaDebuggerCallback callback ,
 	return dma_debugger_queue_append (self, dma_command_new (DMA_LIST_FRAME_COMMAND, callback, user_data));
 }
 
+gboolean
+dma_queue_dump_stack_trace (DmaDebuggerQueue *self, IAnjutaDebuggerCallback callback , gpointer user_data)
+{
+	return dma_debugger_queue_append (self, dma_command_new (DMA_DUMP_STACK_TRACE_COMMAND, callback, user_data));
+}
+
 gboolean
 dma_queue_callback (DmaDebuggerQueue *self, IAnjutaDebuggerCallback callback , gpointer user_data)
 {
@@ -1003,6 +1064,7 @@ dma_command_free (DmaQueueCommand *cmd)
 	case STEPI_IN_COMMAND:
 	case STEPI_OVER_COMMAND:
 	case RUN_TO_ADDRESS_COMMAND:
+	case RUN_FROM_ADDRESS_COMMAND:
 	case EXIT_COMMAND:
 	case INTERRUPT_COMMAND:
 	case ENABLE_BREAK_COMMAND:
@@ -1028,6 +1090,7 @@ dma_command_free (DmaQueueCommand *cmd)
 	    break;
 	case SET_FRAME_COMMAND:
 	case LIST_FRAME_COMMAND:
+	case DUMP_STACK_TRACE_COMMAND:
 	case INSPECT_MEMORY_COMMAND:
 	case DISASSEMBLE_COMMAND:
 		break;
@@ -1038,6 +1101,8 @@ dma_command_free (DmaQueueCommand *cmd)
 		if (cmd->data.watch.value != NULL) g_free (cmd->data.watch.value);
 		break;
 	case START_COMMAND:
+	case CONNECT_COMMAND:
+		if (cmd->data.start.server) g_free (cmd->data.start.server);
 		if (cmd->data.start.args) g_free (cmd->data.start.args);
 		break;
 	case LOAD_COMMAND:
@@ -1057,6 +1122,7 @@ dma_command_free (DmaQueueCommand *cmd)
         g_list_free (cmd->data.attach.dirs);
 		break;
 	case RUN_TO_COMMAND:
+	case RUN_FROM_COMMAND:
 	case BREAK_LINE_COMMAND:
 	case BREAK_FUNCTION_COMMAND:
 	case BREAK_ADDRESS_COMMAND:
@@ -1136,7 +1202,6 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 	gboolean ret = FALSE;
 	DmaDebuggerCommandType type = cmd->type & COMMAND_MASK;
 	IAnjutaDebuggerCallback callback = cmd->callback == NULL ? NULL : dma_debugger_queue_command_callback;
-	GFile* file;
 	switch (type)
 	{
 	case EMPTY_COMMAND:
@@ -1169,12 +1234,18 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 	case START_COMMAND:
 		ret = ianjuta_debugger_start (debugger, cmd->data.start.args, cmd->data.start.terminal, cmd->data.start.stop, err);
 	    break;
+	case CONNECT_COMMAND:
+		ret = ianjuta_debugger_connect (debugger, cmd->data.start.server, cmd->data.start.args, cmd->data.start.terminal, cmd->data.start.stop, err);
+	    break;
 	case RUN_COMMAND:
 		ret = ianjuta_debugger_run (debugger, err);	
 		break;
 	case RUN_TO_COMMAND:
 		ret = ianjuta_debugger_run_to (debugger, cmd->data.pos.file, cmd->data.pos.line, err);
 		break;
+	case RUN_FROM_COMMAND:
+		ret = ianjuta_debugger_run_from (debugger, cmd->data.pos.file, cmd->data.pos.line, err);
+		break;
 	case STEP_IN_COMMAND:
 		ret = ianjuta_debugger_step_in (debugger, err);	
 		break;
@@ -1187,6 +1258,9 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 	case RUN_TO_ADDRESS_COMMAND:
 		ret = ianjuta_debugger_instruction_run_to_address (IANJUTA_DEBUGGER_INSTRUCTION (debugger), cmd->data.pos.address, err);	
 		break;
+	case RUN_FROM_ADDRESS_COMMAND:
+		ret = ianjuta_debugger_instruction_run_from_address (IANJUTA_DEBUGGER_INSTRUCTION (debugger), cmd->data.pos.address, err);	
+		break;
 	case STEPI_IN_COMMAND:
 		ret = ianjuta_debugger_instruction_step_in_instruction (IANJUTA_DEBUGGER_INSTRUCTION (debugger), err);	
 		break;
@@ -1295,6 +1369,9 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 	case LIST_FRAME_COMMAND:
 		ret = ianjuta_debugger_list_frame (debugger, callback, queue, err);	
 		break;
+	case DUMP_STACK_TRACE_COMMAND:
+		ret = ianjuta_debugger_dump_stack_trace (debugger, callback, queue, err);	
+		break;
 	case LIST_REGISTER_COMMAND:
 		ret = ianjuta_debugger_register_list_register (IANJUTA_DEBUGGER_REGISTER (debugger), callback, queue, err);	
 		break;
@@ -1359,14 +1436,17 @@ dma_command_callback (DmaQueueCommand *cmd, const gpointer data, GError *err)
 	case QUIT_COMMAND:
 	case ABORT_COMMAND:
 	case START_COMMAND:
+	case CONNECT_COMMAND:
 	case SET_WORKING_DIRECTORY_COMMAND:
 	case SET_ENVIRONMENT_COMMAND:	
 	case RUN_COMMAND:
 	case RUN_TO_COMMAND:
+	case RUN_FROM_COMMAND:
 	case STEP_IN_COMMAND:
 	case STEP_OVER_COMMAND:
 	case STEP_OUT_COMMAND:
 	case RUN_TO_ADDRESS_COMMAND:
+	case RUN_FROM_ADDRESS_COMMAND:
 	case STEPI_IN_COMMAND:
 	case STEPI_OVER_COMMAND:
 	case EXIT_COMMAND:
@@ -1404,6 +1484,7 @@ dma_command_callback (DmaQueueCommand *cmd, const gpointer data, GError *err)
 	case INFO_UDOT_COMMAND:
 	case INFO_VARIABLES_COMMAND:
 	case LIST_FRAME_COMMAND:
+	case DUMP_STACK_TRACE_COMMAND:
 	case LIST_REGISTER_COMMAND:
 	case UPDATE_REGISTER_COMMAND:
 	case INSPECT_MEMORY_COMMAND:
