@@ -71,9 +71,11 @@ gboolean dma_queue_run (DmaDebuggerQueue *self);
 gboolean dma_queue_step_in (DmaDebuggerQueue *self);
 gboolean dma_queue_step_over (DmaDebuggerQueue *self);
 gboolean dma_queue_run_to (DmaDebuggerQueue *self, const gchar *file, gint line);
+gboolean dma_queue_run_from (DmaDebuggerQueue *self, const gchar *file, gint line);
 gboolean dma_queue_stepi_in (DmaDebuggerQueue *self);
 gboolean dma_queue_stepi_over (DmaDebuggerQueue *self);
 gboolean dma_queue_run_to_address (DmaDebuggerQueue *self, gulong address);
+gboolean dma_queue_run_from_address (DmaDebuggerQueue *self, gulong address);
 gboolean dma_queue_step_out (DmaDebuggerQueue *self);
 gboolean dma_queue_exit (DmaDebuggerQueue *self);
 gboolean dma_queue_interrupt (DmaDebuggerQueue *self);
@@ -97,6 +99,7 @@ gboolean dma_queue_info_udot (DmaDebuggerQueue *self, IAnjutaDebuggerCallback ca
 gboolean dma_queue_info_variables (DmaDebuggerQueue *self, IAnjutaDebuggerCallback callback , gpointer user_data);
 gboolean dma_queue_set_frame (DmaDebuggerQueue *self, guint frame);
 gboolean dma_queue_list_frame (DmaDebuggerQueue *self, IAnjutaDebuggerCallback callback , gpointer user_data);
+gboolean dma_queue_dump_stack_trace (DmaDebuggerQueue *self, IAnjutaDebuggerCallback callback , gpointer user_data);
 gboolean dma_queue_list_register (DmaDebuggerQueue *self, IAnjutaDebuggerCallback callback , gpointer user_data);
 gboolean dma_queue_callback (DmaDebuggerQueue *self, IAnjutaDebuggerCallback callback , gpointer user_data);
 void dma_queue_enable_log (DmaDebuggerQueue *self, IAnjutaMessageView *log);
