@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifndef __FILE_WIZARD_PLUGIN__
@@ -25,7 +25,7 @@
 #include <libanjuta/anjuta-preferences.h>
 #include <libanjuta/anjuta-ui.h>
 
-extern GType project_import_plugin_get_type (AnjutaGluePlugin *plugin);
+extern GType project_import_plugin_get_type (GTypeModule *module);
 #define ANJUTA_TYPE_PLUGIN_PROJECT_IMPORT         (project_import_plugin_get_type (NULL))
 #define ANJUTA_PLUGIN_PROJECT_IMPORT(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), ANJUTA_TYPE_PLUGIN_PROJECT_IMPORT, AnjutaProjectImportPlugin))
 #define ANJUTA_PLUGIN_PROJECT_IMPORT_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST ((k), ANJUTA_TYPE_PLUGIN_PROJECT_IMPORT, AnjutaProjectImportPluginClass))
@@ -40,6 +40,7 @@ struct _AnjutaProjectImportPlugin
 {
 	AnjutaPlugin parent;
 	AnjutaPreferences *prefs;
+	gchar *backend_id;
 };
 
 struct _AnjutaProjectImportPluginClass
