@@ -30,13 +30,17 @@
 #include "header.h"
 
 #include <glib.h>
+#include <glib/gi18n.h>
+
 #include <libanjuta/anjuta-utils.h>
 
 /*---------------------------------------------------------------------------*/
 
 struct _NPWHeader {
 	gchar* name;
+	gint name_lang;
 	gchar* description;
+	gint description_lang;
 	gchar* iconfile;
 	gchar* category;
 	gchar* filename;
@@ -60,6 +64,8 @@ npw_header_new (void)
 void
 npw_header_free (NPWHeader* self)
 {
+	if (self == NULL) return;
+	
 	g_free (self->name);
 	g_free (self->description);
 	g_free (self->iconfile);
@@ -67,23 +73,30 @@ npw_header_free (NPWHeader* self)
 	g_free (self->filename);
 	g_list_free (self->required_programs);
 	g_list_free (self->required_packages);
+	g_slice_free (NPWHeader, self);
 }
 
 void
-npw_header_set_name (NPWHeader* self, const gchar* name)
+npw_header_set_name (NPWHeader* self, const gchar* name, gint lang)
 {
-	self->name = g_strdup (name);
+	if (lang >= self->name_lang)
+	{
+		g_free (self->name);
+		self->name = g_strdup (name);
+		self->name_lang = lang;
+	}
 }
 
 const gchar*
 npw_header_get_name (const NPWHeader* self)
 {
-	return self->name;
+	return self->name_lang == 0 ? _(self->name) : self->name;
 }
 
 void
 npw_header_set_filename (NPWHeader* self, const gchar* filename)
 {
+	g_free (self->filename);
 	self->filename = g_strdup (filename);
 }
 
@@ -96,6 +109,7 @@ npw_header_get_filename (const NPWHeader* self)
 void
 npw_header_set_category (NPWHeader* self, const gchar* category)
 {
+	g_free (self->category);
 	self->category =g_strdup (category);
 }
 
@@ -106,20 +120,26 @@ npw_header_get_category (const NPWHeader* self)
 }
 
 void
-npw_header_set_description (NPWHeader* self, const gchar* description)
+npw_header_set_description (NPWHeader* self, const gchar* description, gint lang)
 {
-	self->description = g_strdup (description);
+	if (lang >= self->description_lang)
+	{
+		g_free (self->description);
+		self->description = g_strdup (description);
+		self->description_lang = lang;
+	}
 }
 
 const gchar*
 npw_header_get_description (const NPWHeader* self)
 {
-	return self->description;
+	return self->description_lang == 0 ? _(self->description) : self->description;
 }
 
 void
 npw_header_set_iconfile (NPWHeader* self, const gchar* iconfile)
 {
+	g_free (self->iconfile);
 	self->iconfile = g_strdup (iconfile);
 }
 
@@ -155,27 +175,14 @@ npw_header_check_required_programs (NPWHeader* self)
 	{
 		if (!anjuta_util_prog_is_installed (node->data, FALSE))
 		{
-			failed_programs = g_list_prepend (failed_programs, node->data);
+			const gchar *const prog = (const gchar *) node->data;
+			failed_programs = g_list_prepend (failed_programs,
+											  g_strdup (prog));
 		}
 	}
 	return failed_programs;
 }
 
-static gboolean
-package_is_installed (const gchar *package)
-{
-	int status;
-	int exit_status;
-	pid_t pid;
-	if ((pid = fork()) == 0)
-	{
-		execlp ("pkg-config", "pkg-config", "--exists", package, NULL);
-	}
-	waitpid (pid, &status, 0);
-	exit_status = WEXITSTATUS (status);
-	return (exit_status == 0);
-}
-
 GList*
 npw_header_check_required_packages (NPWHeader* self)
 {
@@ -183,9 +190,11 @@ npw_header_check_required_packages (NPWHeader* self)
 	GList *failed_packages = NULL;
 	for (node = self->required_packages; node; node = g_list_next (node))
 	{
-		if (!package_is_installed (node->data))
+		if (!anjuta_util_package_is_installed (node->data, FALSE))
 		{
-			failed_packages = g_list_prepend (failed_packages, node->data);
+			const gchar *const pkg = (const gchar *) node->data;
+			failed_packages = g_list_prepend (failed_packages,
+											  g_strdup (pkg));
 		}
 	}
 	return failed_packages;
@@ -221,7 +230,7 @@ npw_header_list_free (GList* list)
 static gint
 compare_header_name (NPWHeader *a, NPWHeader *b)
 {
-	return g_ascii_strcasecmp (npw_header_get_name (a), npw_header_get_name (b));
+	return g_utf8_collate (npw_header_get_name (a), npw_header_get_name (b));
 }
 
 GList *
